@@ -23,13 +23,13 @@ sparql.setQuery("""
 """)
 
 # RDF/XML example
-print '\n\n*** RDF/XML Example'
+print('\n\n*** RDF/XML Example')
 sparql.setReturnFormat(XML)
 results = sparql.query().convert()
 print(results.serialize(format='xml'))
 
 # N3 example
-print '\n\n*** N3 Example'
+print('\n\n*** N3 Example')
 sparql.setReturnFormat(N3)
 results = sparql.query().convert()
 g = Graph()
@@ -37,7 +37,7 @@ g.parse(data=results, format="n3")
 print(g.serialize(format='n3'))
 
 # Turtle example
-print '\n\n*** TURTLE Example'
+print('\n\n*** TURTLE Example')
 sparql.setReturnFormat(TURTLE)
 results = sparql.query().convert()
 g = Graph()
@@ -45,7 +45,7 @@ g.parse(data=results, format="turtle")
 print(g.serialize(format='turtle'))
 
 # JSONLD example
-print '\n\n*** JSONLD Example'
+print('\n\n*** JSONLD Example')
 sparql.setReturnFormat(JSONLD)
 results = sparql.query().convert()
 print(results.serialize(format='json-ld'))
