@@ -13,4 +13,4 @@ DELETE
 """)
 
 results = sparql.query()
-print results.response.read()
\ No newline at end of file
+print(results.response.read())
\ No newline at end of file
